@@ -297,4 +297,20 @@ Asunto:   {0}<br/>
 	'urgent priority' => 'Urgente',
 	'attachment from email' => 'Adjunto al correo "{0}"',
 	'total estimated time' => 'Tiempo estimado total',	
+
+	'emailunclassified' => 'Emails no clasificados',
+	'file' => 'Archivos',
+	'email' => 'Emails',
+	'weblink' => 'Links',
+	'message' => 'Notas',
+	'contact' => 'Contactos',
+	'comment' => 'Comentarios',
+	'webpage' => 'Web links',
+	'company' => 'Organizaciones',
+	'milestone' => 'Hitos',
+	'task' => 'Tareas',
+	'event' => 'Eventos',
+	'objective' => 'Objetivos',
+	'form' => 'Formulario',
+	'linked object tab' => '{0}',
 ); ?>
